// Copyright (c) 2024 Dominic Masters
// 
// This software is released under the MIT License.
// https://opensource.org/licenses/MIT

#include "RPGEntity.hpp"
#include "scene/Scene.hpp"
#include "display/mesh/QuadMesh.hpp"
#include "asset/loader/TextureLoader.hpp"

using namespace Dawn;

void RPGEntity::onInit() {
  const glm::vec2 size = { RPG_ENTITY_SIZE, RPG_ENTITY_SIZE };
  const glm::vec2 position = -size;
  const auto sprites = getGame()->assetManager->get<TextureLoader>("rosa.texture");

  mesh = std::make_shared<Mesh>();
  mesh->createBuffers(QUAD_VERTICE_COUNT, QUAD_INDICE_COUNT);
  QuadMesh::buffer(
    mesh,
    glm::vec4(position.x, position.y, size.x, size.y),
    glm::vec4(0, 1.0f, 1, 0.75f),
    0, 0, 0
  );

  meshRenderer = getItem()->addComponent<MeshRenderer>();
  meshRenderer->mesh = mesh;

  material = getItem()->addComponent<SimpleTexturedMaterial>();
  material->setColor(COLOR_WHITE);
  material->setTexture(sprites->getTexture());
}

void RPGEntity::onDispose() {
  meshRenderer = nullptr;
  mesh = nullptr;
  material = nullptr;
}